@@ -22,6 +22,7 @@ PRESERVED_SIGNATURE_V4 = (
     "policy", "x-amz-credential", "x-amz-algorithm",
     "x-amz-date", "x-amz-signature"
 )
+HTTP_TIMEOUTS = (30, 60)  # first is connection, second is for reading
 
 
 def _order_upload_keys(fields, keys):
@@ -72,7 +73,10 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
 
         if not progress_bar:
             return requests.post(
-                url, data=encoder, headers=headers
+                url,
+                data=encoder,
+                headers=headers,
+                timeout=HTTP_TIMEOUTS,
             )
 
         with ProgressBar(total=encoder.len, unit="bytes", unit_scale=True, leave=False) as bar:
@@ -81,19 +85,28 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
                 lambda monitor: bar.update_to(monitor.bytes_read)
             )
             return requests.post(
-                url, data=monitor, headers=headers
+                url,
+                data=monitor,
+                headers=headers,
+                timeout=HTTP_TIMEOUTS,
             )
     elif provider == 'azure-blob' or provider == 'aws-s3-put':
         return requests.put(
             url,
             data=file,
             headers=destination.get('headers'),
+            timeout=HTTP_TIMEOUTS,
         )
 
 
 @tenacity.retry(stop=tenacity.stop_after_attempt(3))
 def download(source, destination=None, progress_bar=False):
-    r = requests.get(source, stream=True, allow_redirects=True)
+    r = requests.get(
+        source,
+        stream=True,
+        allow_redirects=True,
+        timeout=HTTP_TIMEOUTS,
+    )
     r.raise_for_status()
 
     is_file = False
